<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package NewsAnchor
 */


if ( ! function_exists( 'newsanchor_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function newsanchor_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$posted_on = '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>';

	$byline = sprintf(
		esc_html_x( '%s', 'post author', 'newsanchor' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
	);

	echo '<span class="posted-on date">' . $posted_on . '</span><span class="byline"> ' . $byline . '</span>';

	$categories_list = get_the_category_list( __( ', ', 'newsanchor' ) );
	if ( $categories_list && newsanchor_categorized_blog() ) {
		echo '<span class="categories"> ' . $categories_list . '</span>';
	}

}
endif;

if ( ! function_exists( 'newsanchor_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function newsanchor_entry_footer() {
	// Hide category and tag text for pages.
	if ( 'post' == get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', esc_html__( ' ', 'newsanchor' ) );
		if ( $tags_list ) {
			printf( '<span class="tags-post">' . esc_html__( 'Tagged %1$s', 'newsanchor' ) . '</span>', $tags_list );
		}
	}
}
endif;


/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function newsanchor_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'newsanchor_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'newsanchor_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so newsanchor_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so newsanchor_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in newsanchor_categorized_blog.
 */
function newsanchor_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'newsanchor_categories' );
}
add_action( 'edit_category', 'newsanchor_category_transient_flusher' );
add_action( 'save_post',     'newsanchor_category_transient_flusher' );
